@@ -92,8 +92,8 @@ class WebView(WebKit2.WebView):
         """
         try:
             zoom_level = self._window.zoom_level
-            if self.__related_view is not None:
-                window = self.__related_view.get_ancestor(Gtk.Window)
+            if self._related_view is not None:
+                window = self._related_view.get_ancestor(Gtk.Window)
                 if window is not None and hasattr(window, "zoom_level"):
                     zoom_level = window.zoom_level
             else:
@@ -164,7 +164,7 @@ class WebView(WebKit2.WebView):
             Set delayed uri
             @param uri as str
         """
-        self.__uri = uri
+        self._uri = uri
         self.emit("uri-changed", uri)
 
     def update_spell_checking(self, uri):
@@ -402,10 +402,7 @@ class WebView(WebKit2.WebView):
             Get uri (loaded or unloaded)
             @return str
         """
-        uri = self.get_uri()
-        if uri is None:
-            uri = self.__uri
-        return uri
+        return self._uri
 
     @property
     def netloc(self):
@@ -461,10 +458,10 @@ class WebView(WebKit2.WebView):
         # it from clipboard FIXME Get it from extensions
         self.__selection = ""
         self._readable = False
-        self.__uri = None
+        self._uri = None
         self._initial_uri = None
         self._title = None
-        self.__related_view = related_view
+        self._related_view = related_view
         self._shown = False
         self.set_hexpand(True)
         self.set_vexpand(True)
@@ -492,13 +489,15 @@ class WebView(WebKit2.WebView):
                                       App().settings.get_value(
                                           "font-serif").get_string())
             settings.set_property("auto-load-images", True)
+            settings.set_hardware_acceleration_policy(
+                WebKit2.HardwareAccelerationPolicy.NEVER)
             settings.set_property("enable-site-specific-quirks", True)
             settings.set_property("allow-universal-access-from-file-urls",
                                   False)
             settings.set_property("allow-file-access-from-file-urls", False)
             settings.set_property("enable-javascript", True)
             settings.set_property("enable-media-stream", True)
-            settings.set_property("enable-mediasource", False)
+            settings.set_property("enable-mediasource", True)
             autoplay_videos = App().settings.get_value('autoplay-videos')
             # Setting option to False make video playback buggy
             if not autoplay_videos:
@@ -550,11 +549,13 @@ class WebView(WebKit2.WebView):
         webview = WebView.new_with_related_view(related, self._window)
         webview.set_atime(related.atime - 1)
         elapsed = time() - related._last_click_time
+        uri = navigation_action.get_request().get_uri()
         webview.connect("ready-to-show",
                         self.__on_ready_to_show,
                         related,
                         navigation_action,
                         elapsed)
+        webview.set_uri(uri)
         webview.set_parent(self)
         self.add_child(webview)
         return webview
@@ -617,9 +618,10 @@ class WebViewMeta(WebViewNavigation, WebView, WebViewErrors,
             @param webview as WebView
             @param event as WebKit2.LoadEvent
         """
-        self.__uri = webview.get_uri()
-        if event == WebKit2.LoadEvent.STARTED:
-            self.__new_pages_opened = 0
         WebViewNavigation._on_load_changed(self, webview, event)
         WebViewSignals._on_load_changed(self, webview, event)
         WebViewArtwork._on_load_changed(self, webview, event)
+        if event == WebKit2.LoadEvent.STARTED:
+            self.__new_pages_opened = 0
+        elif event == WebKit2.LoadEvent.COMMITTED:
+            self._uri = webview.get_uri()
